# Generated by Django 5.1.7 on 2025-03-16 19:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('user', '0004_user_login_alter_user_email_user_email_or_login_set'),
    ]

    operations = [
        migrations.RemoveConstraint(
            model_name='user',
            name='email_or_login_set',
        ),
        migrations.AddConstraint(
            model_name='user',
            constraint=models.CheckConstraint(condition=models.Q(('email__isnull', False), ('login__isnull', False), _connector='OR'), name='email_or_login_set', violation_error_message='email or login must be set'),
        ),
    ]
