{% if detail_header_template %}
    <div hx-swap-oob="innerHTML:#detail-header">
        {% include detail_header_template %}
    </div>
{% endif %}

{% if detail_data_template %}
    <div hx-swap-oob="innerHTML:#detail-data">
        {% include detail_data_template %}
    </div>
{% endif %}
