{% extends 'ui/modal.html' %}
{% load i18n %}
{% load ui %}

{% block modal_content %}
    <form id="{{ modal_id }}-form" hx-post="{% url 'user:change_email' %}">
        {% csrf_token %}
        {{ form.email|wrap_form_field }}
        {{ form.password|wrap_form_field }}
    </form>
{% endblock %}

{% block modal_buttons %}
	<button type="submit" form="{{ modal_id }}-form" class="button is-success">{% translate 'Save' %}</button>
    {{ block.super }}
{% endblock %}

