# Generated by Django 5.1.1 on 2025-01-12 09:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('log', '0004_logconfig_logconfigfield'),
    ]

    operations = [
        migrations.AddField(
            model_name='logconfig',
            name='exclude_fields',
            field=models.BooleanField(default=False, help_text='If set, Log Configuration Fields will be excluded from logging. Otherwise only configured fields will be logged.', verbose_name='Exclude Fields'),
        ),
        migrations.AlterField(
            model_name='logconfig',
            name='ignore_errors',
            field=models.BooleanField(default=False, help_text='If set, exceptions during log creation will be ignored', verbose_name='Ignore Errors'),
        ),
        migrations.AlterField(
            model_name='logconfigfield',
            name='log_config',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='fields', to='log.logconfig', verbose_name='Log Configuration'),
        ),
    ]
