{% load i18n %}

<div class="query-operator my-1">
    <span class="select is-small">
        <select name="query_operator_select" class="query-operator-select" aria-label="Select Operation" x-on:change="applyQuery()">
            <option value="&" {% if operator == '&' %}selected{% endif %}>{% translate 'AND' %}</option>
            <option value="|" {% if operator == '|' %}selected{% endif %}>{% translate 'OR' %}</option>
            <option value="^" {% if operator == '^' %}selected{% endif %}>{% translate 'XOR' %}</option>
        </select>
    </span>
</div>