{% extends 'user/login.html' %}

{% load i18n %}
{% block theme %}data-theme="light"{% endblock %}
{% block title %}{% translate 'Registration' %}{% endblock %}

{% block hero_body %}
<div class="container">
    <div class="columns">
        <div class="column box is-8-tablet is-offset-2-tablet is-6-desktop is-offset-3-desktop is-4-fullhd is-offset-4-fullhd">
            {% block form %}
                <form method="POST" action="" id="customer-form">
                    {% csrf_token %}
                    <span class="has-text-danger is-size-7">{{ form.non_field_errors }}</span>

                    <label class="label">{{ form.email.label_tag }}
                        {{ form.email }}
                        <span class="has-text-danger is-size-7">{{ form.email.errors }}</span>
                    </label>

                    <label class="label">{{ form.password1.label_tag }}
                        {{ form.password1 }}
                        <span class="has-text-danger is-size-7">{{ form.password1.errors }}</span>
                    </label>


                    <label class="label">{{ form.password2.label_tag }}
                        {{ form.password2 }}
                        <span class="has-text-danger is-size-7">{{ form.password2.errors }}</span>
                    </label>

                    <input type="submit" class="button is-fullwidth is-success is-medium" value="{% translate 'Register' %}">
                </form>
            {% endblock %}
        </div>
    </div>
</div>
{% endblock %}

