# Generated by Django 5.1.4 on 2025-02-24 17:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accrete', '0003_remove_member_name'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='AccessGroupMember',
            new_name='MemberAccessGroupRel',
        ),
        migrations.RenameModel(
            old_name='TenantAccessGroup',
            new_name='TenantAccessGroupRel',
        ),
        migrations.AlterModelOptions(
            name='memberaccessgrouprel',
            options={'ordering': ['member'], 'verbose_name': 'Member Access Group Relation', 'verbose_name_plural': 'Member Access Group Relations'},
        ),
        migrations.AlterModelOptions(
            name='tenantaccessgrouprel',
            options={'ordering': ['tenant'], 'verbose_name': 'Tenant Access Group Relation', 'verbose_name_plural': 'Tenant Access Groups Relations'},
        ),
        migrations.RemoveField(
            model_name='accessgroup',
            name='is_public',
        ),
        migrations.AlterField(
            model_name='accessgroup',
            name='code',
            field=models.CharField(max_length=100, verbose_name='Code'),
        ),
        migrations.AlterModelTable(
            name='memberaccessgrouprel',
            table='accrete_member_access_group_rel',
        ),
    ]
