# Generated by Django 5.2.1 on 2025-08-08 06:13

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('accrete', '0009_alter_accessgroup_name'),
        ('ui', '0002_alter_theme_color_danger_alter_theme_color_link_and_more'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AlterConstraint(
            model_name='theme',
            name='check_user_or_tenant',
            constraint=models.CheckConstraint(condition=models.Q(('user__isnull', True), ('tenant__isnull', True), _connector='XOR'), name='check_user_or_tenant', violation_error_message='A theme must be assigned either to a user or a tenant.'),
        ),
    ]
