{% load partials %}

{% partialdef header inline=True %}
    <div id="detail-header" class="is-flex is-flex-wrap-wrap is-flex-grow-1">
        {% block header %}{% endblock %}
    </div>
{% endpartialdef %}

{% partialdef content inline=True %}
    <div id="detail" style="overflow-y: auto; height: 100%;">
        {% block content %}{% endblock %}
    </div>
{% endpartialdef %}
