# Generated by Django 5.1.4 on 2025-02-19 18:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('country', '0002_auto_20250219_1759'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='country',
            options={'ordering': ['-order_priority', 'name'], 'verbose_name': 'Country', 'verbose_name_plural': 'Countries'},
        ),
    ]
